# coding: utf-8

# flake8: noqa

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CambAI",
    "AudioSeparationApi",
    "DictionariesApi",
    "DubApi",
    "StoriesApi",
    "TextToAudioApi",
    "TextToSpeechApi",
    "TextToVoiceApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AudioOutputFileURLResponse",
    "AudioOutputType",
    "AudioSeparationRunInfoResponse",
    "BodyTranslateTranslatePost",
    "CreateAPIKeyRequestPayload",
    "CreateCustomVoiceOut",
    "CreateTTSRequestPayload",
    "CreateTTSStreamRequestPayload",
    "CreateTextToAudioRequestPayload",
    "CreateTextToVoiceRequestPayload",
    "CreateTranslatedStoryRequestPayload",
    "CreateTranslatedTTSRequestPayload",
    "CreateTranslationStreamRequestPayload",
    "DialogueItem",
    "Dictionary",
    "DubAltFormatResponseBody",
    "DubbedOutputInAltFormatRequestPayload",
    "EndToEndDubbingRequestPayload",
    "ExpireAPIKeyRequestPayload",
    "Formalities",
    "Gender",
    "HTTPValidationError",
    "LanguageItem",
    "Languages",
    "OrchestratorPipelineResult",
    "OutputAPIKey",
    "OutputFormat",
    "OutputType",
    "RequestDubbedOutputInAltFormat200Response",
    "RunInfoResponse",
    "StoryRunInfoResponse",
    "TTSStreamOutputFormat",
    "TaskID",
    "TaskStatus",
    "TextToVoiceRunInfoResponse",
    "TranscriptDataType",
    "TranscriptFileFormat",
    "TranslationResult",
    "ValidationError",
    "ValidationErrorLocInner",
    "VideoOutputTypeWithoutAVI",
    "VoiceItem",
]

# import apis into sdk package
from cambai.api.apis_api import CambAI as CambAI
from cambai.api.audio_separation_api import AudioSeparationApi as AudioSeparationApi
from cambai.api.dictionaries_api import DictionariesApi as DictionariesApi
from cambai.api.dub_api import DubApi as DubApi
from cambai.api.stories_api import StoriesApi as StoriesApi
from cambai.api.text_to_audio_api import TextToAudioApi as TextToAudioApi
from cambai.api.text_to_speech_api import TextToSpeechApi as TextToSpeechApi
from cambai.api.text_to_voice_api import TextToVoiceApi as TextToVoiceApi

# import ApiClient
from cambai.api_response import ApiResponse as ApiResponse
from cambai.api_client import ApiClient as ApiClient
from cambai.configuration import Configuration as Configuration
from cambai.exceptions import OpenApiException as OpenApiException
from cambai.exceptions import ApiTypeError as ApiTypeError
from cambai.exceptions import ApiValueError as ApiValueError
from cambai.exceptions import ApiKeyError as ApiKeyError
from cambai.exceptions import ApiAttributeError as ApiAttributeError
from cambai.exceptions import ApiException as ApiException

# import models into sdk package
from cambai.models.audio_output_file_url_response import AudioOutputFileURLResponse as AudioOutputFileURLResponse
from cambai.models.audio_output_type import AudioOutputType as AudioOutputType
from cambai.models.audio_separation_run_info_response import AudioSeparationRunInfoResponse as AudioSeparationRunInfoResponse
from cambai.models.body_translate_translate_post import BodyTranslateTranslatePost as BodyTranslateTranslatePost
from cambai.models.create_api_key_request_payload import CreateAPIKeyRequestPayload as CreateAPIKeyRequestPayload
from cambai.models.create_custom_voice_out import CreateCustomVoiceOut as CreateCustomVoiceOut
from cambai.models.create_tts_request_payload import CreateTTSRequestPayload as CreateTTSRequestPayload
# from cambai.models.create_tts_stream_request_payload import CreateTTSStreamRequestPayload as CreateTTSStreamRequestPayload
from cambai.models.create_text_to_audio_request_payload import CreateTextToAudioRequestPayload as CreateTextToAudioRequestPayload
from cambai.models.create_text_to_voice_request_payload import CreateTextToVoiceRequestPayload as CreateTextToVoiceRequestPayload
from cambai.models.create_translated_story_request_payload import CreateTranslatedStoryRequestPayload as CreateTranslatedStoryRequestPayload
from cambai.models.create_translated_tts_request_payload import CreateTranslatedTTSRequestPayload as CreateTranslatedTTSRequestPayload
from cambai.models.create_translation_stream_request_payload import CreateTranslationStreamRequestPayload as CreateTranslationStreamRequestPayload
from cambai.models.dialogue_item import DialogueItem as DialogueItem
from cambai.models.dictionary import Dictionary as Dictionary
from cambai.models.dub_alt_format_response_body import DubAltFormatResponseBody as DubAltFormatResponseBody
from cambai.models.dubbed_output_in_alt_format_request_payload import DubbedOutputInAltFormatRequestPayload as DubbedOutputInAltFormatRequestPayload
from cambai.models.end_to_end_dubbing_request_payload import EndToEndDubbingRequestPayload as EndToEndDubbingRequestPayload
from cambai.models.expire_api_key_request_payload import ExpireAPIKeyRequestPayload as ExpireAPIKeyRequestPayload
from cambai.models.formalities import Formalities as Formalities
from cambai.models.gender import Gender as Gender
from cambai.models.http_validation_error import HTTPValidationError as HTTPValidationError
from cambai.models.language_item import LanguageItem as LanguageItem
from cambai.models.languages import Languages as Languages
from cambai.models.orchestrator_pipeline_result import OrchestratorPipelineResult as OrchestratorPipelineResult
from cambai.models.output_api_key import OutputAPIKey as OutputAPIKey
from cambai.models.output_format import OutputFormat as OutputFormat
from cambai.models.output_type import OutputType as OutputType
from cambai.models.request_dubbed_output_in_alt_format200_response import RequestDubbedOutputInAltFormat200Response as RequestDubbedOutputInAltFormat200Response
from cambai.models.run_info_response import RunInfoResponse as RunInfoResponse
from cambai.models.story_run_info_response import StoryRunInfoResponse as StoryRunInfoResponse
from cambai.models.tts_stream_output_format import TTSStreamOutputFormat as TTSStreamOutputFormat
from cambai.models.task_id import TaskID as TaskID
from cambai.models.task_status import TaskStatus as TaskStatus
from cambai.models.text_to_voice_run_info_response import TextToVoiceRunInfoResponse as TextToVoiceRunInfoResponse
from cambai.models.transcript_data_type import TranscriptDataType as TranscriptDataType
from cambai.models.transcript_file_format import TranscriptFileFormat as TranscriptFileFormat
from cambai.models.translation_result import TranslationResult as TranslationResult
from cambai.models.validation_error import ValidationError as ValidationError
from cambai.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner
from cambai.models.video_output_type_without_avi import VideoOutputTypeWithoutAVI as VideoOutputTypeWithoutAVI
from cambai.models.voice_item import VoiceItem as VoiceItem
