# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import os
import unittest

from cambai.api.apis_api import CambAI


class TestApisApi(unittest.TestCase):
    """ApisApi unit test stubs"""

    def setUp(self) -> None:
        api_key = "CAMB_API_KEY"
        self.api = CambAI(api_key=api_key)

    def tearDown(self) -> None:
        pass

    def test_create_audio_separation(self) -> None:
        """Test case for create_audio_separation

        Create Audio Separation
        """
        pass

    def test_create_custom_voice(self) -> None:
        """Test case for create_custom_voice

        Create Custom Voice
        """
        pass

    def test_create_end_to_end_dubbing(self) -> None:
        """Test case for create_end_to_end_dubbing

        End To End Dubbing
        """
        pass

    def test_create_story(self) -> None:
        """Test case for create_story

        Create Story
        """
        pass

    def test_create_text_to_sound(self) -> None:
        """Test case for create_text_to_sound

        Create Text to Sound
        """
        pass

    def test_create_transcription(self) -> None:
        """Test case for create_transcription

        Create Transcription
        """
        pass

    def test_create_translated_story(self) -> None:
        """Test case for create_translated_story

        Create Translated Story
        """
        pass

    def test_create_translated_tts(self) -> None:
        """Test case for create_translated_tts

        Create Translated Tts
        """
        pass

    def test_create_translation(self) -> None:
        """Test case for create_translation

        Create Translation
        """
        pass

    def test_create_translation_stream(self) -> None:
        """Test case for create_translation_stream

        Create Translation Stream
        """
        pass

    def test_create_tts(self) -> None:
        """Test case for create_tts

        Create Tts
        """
        pass

    # def test_create_tts_stream(self) -> None:
    #     """Test case for create_tts_stream

    #     Create TTS Stream
    #     """
    #     pass

    def test_create_voice_from_description(self) -> None:
        """Test case for create_voice_from_description

        Create Voice from Description
        """
        pass

    def test_dictionaries_get(self) -> None:
        """Test case for dictionaries_get

        Get Workspace Dictionaries
        """
        pass

    def test_get_audio_separation_run_info_by_id(self) -> None:
        """Test case for get_audio_separation_run_info_by_id

        Get Audio Separation Run Info
        """
        pass

    def test_get_audio_separation_status_by_id(self) -> None:
        """Test case for get_audio_separation_status_by_id

        Get Audio Separation Status
        """
        pass

    def test_get_dubbed_run_info_by_id(self) -> None:
        """Test case for get_dubbed_run_info_by_id

        Get Dubbed Run Info
        """
        pass

    def test_get_end_to_end_dubbing_status_by_id(self) -> None:
        """Test case for get_end_to_end_dubbing_status_by_id

        Get End To End Dubbing Status
        """
        pass

    def test_get_source_languages(self) -> None:
        """Test case for get_source_languages

        Get Source Languages
        """
        pass

    def test_get_story_run_info_by_id(self) -> None:
        """Test case for get_story_run_info_by_id

        Get Story Run Info
        """
        pass

    def test_get_story_status_by_id(self) -> None:
        """Test case for get_story_status_by_id

        Get Story Status
        """
        pass

    def test_get_target_languages(self) -> None:
        """Test case for get_target_languages

        Get Target Languages
        """
        pass

    def test_get_text_to_audio_status_by_id(self) -> None:
        """Test case for get_text_to_audio_status_by_id

        Get Text To Audio Status
        """
        pass

    def test_get_text_to_sound_run_result_by_id(self) -> None:
        """Test case for get_text_to_sound_run_result_by_id

        Get Text to Sound Run Result
        """
        pass

    def test_get_text_to_voice_run_result_by_id(self) -> None:
        """Test case for get_text_to_voice_run_result_by_id

        Get Text-to-Voice Run Result
        """
        pass

    def test_get_transcription_result_by_id(self) -> None:
        """Test case for get_transcription_result_by_id

        Get Transcription Result
        """
        pass

    def test_get_transcription_task_status_by_id(self) -> None:
        """Test case for get_transcription_task_status_by_id

        Create Transcription Task Status
        """
        pass

    def test_get_translated_story_run_info(self) -> None:
        """Test case for get_translated_story_run_info

        Get Translated Story Run Info
        """
        pass

    def test_get_translated_story_status_by_id(self) -> None:
        """Test case for get_translated_story_status_by_id

        Get Translated Story Status
        """
        pass

    def test_get_translated_tts_task_status_by_id(self) -> None:
        """Test case for get_translated_tts_task_status_by_id

        Create Translated Tts Task Status
        """
        pass

    def test_get_translation_result_by_id(self) -> None:
        """Test case for get_translation_result_by_id

        Get Translation Result
        """
        pass

    def test_get_translation_task_status_by_id(self) -> None:
        """Test case for get_translation_task_status_by_id

        Create translation Task Status
        """
        pass

    def test_get_tts_result_by_id(self) -> None:
        """Test case for get_tts_result_by_id

        Get Tts Result
        """
        pass

    def test_get_tts_run_info_by_id(self) -> None:
        """Test case for get_tts_run_info_by_id

        Get Tts Run Info
        """
        pass

    def test_list_voices(self) -> None:
        """Test case for list_voices

        List Voices
        """
        pass

    def test_text_to_voice_task_id_get(self) -> None:
        """Test case for text_to_voice_task_id_get

        Get Text-to-Voice Task Status
        """
        pass


if __name__ == '__main__':
    unittest.main()
