# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.stories_api import StoriesApi


class TestStoriesApi(unittest.TestCase):
    """StoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StoriesApi()

    def tearDown(self) -> None:
        pass

    def test_create_story(self) -> None:
        """Test case for create_story

        Create Story
        """
        pass

    def test_create_translated_story(self) -> None:
        """Test case for create_translated_story

        Create Translated Story
        """
        pass

    def test_get_story_run_info_by_id(self) -> None:
        """Test case for get_story_run_info_by_id

        Get Story Run Info
        """
        pass

    def test_get_translated_story_run_info(self) -> None:
        """Test case for get_translated_story_run_info

        Get Translated Story Run Info
        """
        pass

    def test_get_translated_story_status_by_id(self) -> None:
        """Test case for get_translated_story_status_by_id

        Get Translated Story Status
        """
        pass


if __name__ == '__main__':
    unittest.main()
