# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.audio_separation_api import AudioSeparationApi


class TestAudioSeparationApi(unittest.TestCase):
    """AudioSeparationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AudioSeparationApi()

    def tearDown(self) -> None:
        pass

    def test_create_audio_separation(self) -> None:
        """Test case for create_audio_separation

        Create Audio Separation
        """
        pass

    def test_get_audio_separation_run_info_by_id(self) -> None:
        """Test case for get_audio_separation_run_info_by_id

        Get Audio Separation Run Info
        """
        pass

    def test_get_audio_separation_status_by_id(self) -> None:
        """Test case for get_audio_separation_status_by_id

        Get Audio Separation Status
        """
        pass


if __name__ == '__main__':
    unittest.main()
