# # coding: utf-8

# """
#     FastAPI

#     No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

#     The version of the OpenAPI document: 0.1.0
#     Generated by OpenAPI Generator (https://openapi-generator.tech)

#     Do not edit the class manually.
# """  # noqa: E501


# import unittest

# from cambai.models.create_tts_stream_request_payload import CreateTTSStreamRequestPayload

# class TestCreateTTSStreamRequestPayload(unittest.TestCase):
#     """CreateTTSStreamRequestPayload unit test stubs"""

#     def setUp(self):
#         pass

#     def tearDown(self):
#         pass

#     def make_instance(self, include_optional) -> CreateTTSStreamRequestPayload:
#         """Test CreateTTSStreamRequestPayload
#             include_optional is a boolean, when False only required
#             params are included, when True both required and
#             optional params are included """
#         # uncomment below to create an instance of `CreateTTSStreamRequestPayload`
#         """
#         model = CreateTTSStreamRequestPayload()
#         if include_optional:
#             return CreateTTSStreamRequestPayload(
#                 text = '',
#                 voice_id = 56,
#                 language = 1,
#                 gender = 0,
#                 age = 56,
#                 output_format = 'wav'
#             )
#         else:
#             return CreateTTSStreamRequestPayload(
#                 text = '',
#                 voice_id = 56,
#                 language = 1,
#         )
#         """

#     def testCreateTTSStreamRequestPayload(self):
#         """Test CreateTTSStreamRequestPayload"""
#         # inst_req_only = self.make_instance(include_optional=False)
#         # inst_req_and_optional = self.make_instance(include_optional=True)

# if __name__ == '__main__':
#     unittest.main()
