# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.dub_api import DubApi


class TestDubApi(unittest.TestCase):
    """DubApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DubApi()

    def tearDown(self) -> None:
        pass

    def test_get_dubbed_output_in_alt_format_status_by_id(self) -> None:
        """Test case for get_dubbed_output_in_alt_format_status_by_id

        Get Dubbed Output in Alt Format Status
        """
        pass

    def test_get_dubbed_run_transcript(self) -> None:
        """Test case for get_dubbed_run_transcript

        Get Dubbed Run Transcript
        """
        pass

    def test_request_dubbed_output_in_alt_format(self) -> None:
        """Test case for request_dubbed_output_in_alt_format

        Get Dubbed Output in Alt Format
        """
        pass


if __name__ == '__main__':
    unittest.main()
