# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.models.run_info_response import RunInfoResponse

class TestRunInfoResponse(unittest.TestCase):
    """RunInfoResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RunInfoResponse:
        """Test RunInfoResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RunInfoResponse`
        """
        model = RunInfoResponse()
        if include_optional:
            return RunInfoResponse(
                run_id = 56,
                output_video_url = '',
                output_audio_url = '',
                transcript = [
                    cambai.models.dialogue_item.DialogueItem(
                        start = 1.337, 
                        end = 1.337, 
                        text = '', 
                        speaker = '', )
                    ]
            )
        else:
            return RunInfoResponse(
        )
        """

    def testRunInfoResponse(self):
        """Test RunInfoResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
