# # coding: utf-8

# """
#     FastAPI

#     No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

#     The version of the OpenAPI document: 0.1.0
#     Generated by OpenAPI Generator (https://openapi-generator.tech)

#     Do not edit the class manually.
# """  # noqa: E501


# import unittest

# from cambai.models.tts_stream_output_format import TTSStreamOutputFormat

# class TestTTSStreamOutputFormat(unittest.TestCase):
#     """TTSStreamOutputFormat unit test stubs"""

#     def setUp(self):
#         pass

#     def tearDown(self):
#         pass

#     def testTTSStreamOutputFormat(self):
#         """Test TTSStreamOutputFormat"""
#         # inst = TTSStreamOutputFormat()

# if __name__ == '__main__':
#     unittest.main()
